@@ -5,7 +5,7 @@ from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.template import Template, Context
 
-from caretaker.main_utils import log
+from caretaker.utils import log, file
 
 
 class Command(BaseCommand):
@@ -16,7 +16,9 @@ class Command(BaseCommand):
     help = "Gets a terraform setup configuration"
 
     @staticmethod
-    def _output_terraform_file(output_directory, terraform_file, file_name):
+    def _output_terraform_file(output_directory: Path, terraform_file: Path,
+                               file_name: str) -> Path | None:
+
         with terraform_file.open('r') as in_file:
             # render the terraform file into a template
             t = Template(in_file.read())
@@ -25,15 +27,18 @@ class Command(BaseCommand):
 
             # create the file structure
             output_directory.mkdir(parents=True, exist_ok=True)
+            output_file = (output_directory / file_name)
 
             # write the terraform file to this directory
-            with (output_directory / file_name).open('w') as out_file:
+            with output_file.open('w') as out_file:
                 out_file.write(rendered)
 
+            return output_file
+
     @staticmethod
-    def generate_terraform(output_directory):
+    def generate_terraform(output_directory: str) -> Path | None:
         logger = log.get_logger('caretaker')
-        output_directory = Path(output_directory).expanduser()
+        output_directory = file.normalize_path(output_directory)
 
         # configure file paths
         terraform_dir = Path(
@@ -50,6 +55,8 @@ class Command(BaseCommand):
         logger.info('Terraform files were written to {}'.format(
             output_directory))
 
+        return output_directory
+
     def add_arguments(self, parser):
         parser.add_argument('--output-directory',
                             default='~/terraform_configuration')
